@@ -15,7 +15,7 @@
 #include <bonobo/bonobo-main.h>
 #include <gconf/gconf-client.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <libedataserver/e-component-listener.h>
 
 #include "e-book-marshal.h"
@@ -59,6 +59,8 @@ static GObjectClass *parent_class;
 enum {
 	OPEN_PROGRESS,
 	WRITABLE_STATUS,
+	CONNECTION_STATUS,
+	AUTH_REQUIRED,
 	BACKEND_DIED,
 	LAST_SIGNAL
 };
@@ -109,6 +111,7 @@ struct _EBookPrivate {
 
 	/* cached writable status */
 	gboolean writable;
+	gboolean connected;
 
 	EBookListener         *listener;
 	EComponentListener    *comp_listener;
@@ -131,6 +134,8 @@ struct _EBookPrivate {
 	gulong died_signal;
 
 	gint writable_idle_id;
+	gint connection_idle_id;
+	gint auth_idle_id;
 };
 
 
@@ -206,7 +211,6 @@ e_book_clear_op (EBook *book,
 	e_book_op_free (op);
 }
 
-
 
 static gboolean
 do_add_contact (gboolean          sync,
@@ -315,11 +319,11 @@ do_add_contact (gboolean          sync,
  * e_book_add_contact:
  * @book: an #EBook
  * @contact: an #EContact
- * @error: a #GError to set on failure.
+ * @error: a #GError to set on failure
  *
- * adds @contact to @book.
+ * Adds @contact to @book.
  *
- * Return value: #TRUE if successful, #FALSE otherwise.
+ * Return value: %TRUE if successful, %FALSE otherwise.
  **/
 gboolean
 e_book_add_contact (EBook           *book,
@@ -336,6 +340,17 @@ e_book_add_contact (EBook           *book,
 			       NULL, NULL);
 }
 
+/**
+ * e_book_async_add_contact:
+ * @book: an #EBook
+ * @contact: an #EContact
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Adds @contact to @book without blocking. 
+ *
+ * Return value: %TRUE if the operation was started, %FALSE otherwise.
+ **/
 gboolean
 e_book_async_add_contact (EBook                 *book,
 			  EContact              *contact,
@@ -397,12 +412,11 @@ e_book_response_add_contact (EBook       *book,
 	}
 
 	op->id = g_strdup (id);
+	op->status = status;
 
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
-
 		g_cond_signal (op->cond);
 
 		g_mutex_unlock (op->mutex);
@@ -524,10 +538,10 @@ do_commit_contact (gboolean        sync,
  * @contact: an #EContact
  * @error: a #GError to set on failure
  *
- * applies the changes made to @contact to the stored version in
+ * Applies the changes made to @contact to the stored version in
  * @book.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_commit_contact (EBook           *book,
@@ -543,6 +557,18 @@ e_book_commit_contact (EBook           *book,
 				  
 }
 
+/**
+ * e_book_async_commit_contact:
+ * @book: an #EBook
+ * @contact: an #EContact
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Applies the changes made to @contact to the stored version in
+ * @book without blocking.
+ *
+ * Return value: %TRUE if the operation was started, %FALSE otherwise.
+ **/
 guint
 e_book_async_commit_contact (EBook                 *book,
 			     EContact              *contact,
@@ -740,6 +766,19 @@ do_get_supported_fields (gboolean             sync,
 	}
 }
 
+/**
+ * e_book_get_required_fields:
+ * @book: an #EBook
+ * @fields: a #GList of fields to set on success
+ * @error: a #GError to set on failure
+ *
+ * Gets a list of fields that are required to be filled in for
+ * all contacts in this @book. The list will contain pointers
+ * to allocated strings, and both the #GList and the strings
+ * must be freed by the caller.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise.
+ **/
 gboolean
 e_book_get_required_fields  (EBook            *book,
 			      GList           **fields,
@@ -753,6 +792,17 @@ e_book_get_required_fields  (EBook            *book,
 					NULL, NULL);
 }
 
+/**
+ * e_book_async_get_required_fields:
+ * @book: an #EBook
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Gets a list of fields that are required to be filled in for
+ * all contacts in this @book. This function does not block.
+ *
+ * Return value: %TRUE if the operation was started, %FALSE otherwise.
+ **/
 guint
 e_book_async_get_required_fields (EBook              *book,
 				   EBookEListCallback  cb,
@@ -768,13 +818,15 @@ e_book_async_get_required_fields (EBook              *book,
 /**
  * e_book_get_supported_fields:
  * @book: an #EBook
- * @fields: a #GList
+ * @fields: a #GList of fields to set on success
  * @error: a #GError to set on failure
  *
- * Queries @book for the list of fields it supports. Mostly for use
- * by the contact editor so it knows what fields to sensitize.
+ * Gets a list of fields that can be stored for contacts
+ * in this @book. Other fields may be discarded. The list
+ * will contain pointers to allocated strings, and both the
+ * #GList and the strings must be freed by the caller.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_get_supported_fields  (EBook            *book,
@@ -789,6 +841,18 @@ e_book_get_supported_fields  (EBook            *book,
 					NULL, NULL);
 }
 
+/**
+ * e_book_async_get_supported_fields:
+ * @book: an #EBook
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Gets a list of fields that can be stored for contacts
+ * in this @book. Other fields may be discarded. This
+ * function does not block.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise.
+ **/
 guint
 e_book_async_get_supported_fields (EBook              *book,
 				   EBookEListCallback  cb,
@@ -844,10 +908,10 @@ e_book_response_get_required_fields (EBook       *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
 		op->list = fields;
 
 		g_cond_signal (op->cond);
@@ -894,10 +958,10 @@ e_book_response_get_supported_fields (EBook       *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
 		op->list = fields;
 
 		g_cond_signal (op->cond);
@@ -1022,12 +1086,14 @@ do_get_supported_auth_methods (gboolean             sync,
 /**
  * e_book_get_supported_auth_methods:
  * @book: an #EBook
- * @auth_methods: a #GList
+ * @auth_methods: a #GList of auth methods to set on success
  * @error: a #GError to set on failure
  *
  * Queries @book for the list of authentication methods it supports.
+ * The list will contain pointers to allocated strings, and both the
+ * #GList and the strings must be freed by the caller.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_get_supported_auth_methods (EBook            *book,
@@ -1042,7 +1108,17 @@ e_book_get_supported_auth_methods (EBook            *book,
 					      NULL, NULL);
 }
 
-
+/**
+ * e_book_async_get_supported_auth_methods:
+ * @book: an #EBook
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Queries @book for the list of authentication methods it supports.
+ * This function does not block.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise.
+ **/
 guint
 e_book_async_get_supported_auth_methods (EBook              *book,
 					 EBookEListCallback  cb,
@@ -1073,10 +1149,10 @@ e_book_response_get_supported_auth_methods (EBook                 *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
 		op->list = auth_methods;
 
 		g_cond_signal (op->cond);
@@ -1212,7 +1288,7 @@ do_authenticate_user (gboolean        sync,
  * @auth_method.  @auth_method must be one of the authentication
  * methods returned using e_book_get_supported_auth_methods.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_authenticate_user (EBook         *book,
@@ -1231,6 +1307,22 @@ e_book_authenticate_user (EBook         *book,
 				     NULL, NULL);
 }
 
+/**
+ * e_book_async_authenticate_user:
+ * @book: an #EBook
+ * @user: user name
+ * @passwd: password
+ * @auth_method: string indicating authentication method
+ * @cb: function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Authenticate @user with @passwd, using the auth method
+ * @auth_method. @auth_method must be one of the authentication
+ * methods returned using e_book_get_supported_auth_methods.
+ * This function does not block.
+ *
+ * Return value: %FALSE if successful, %TRUE otherwise.
+ **/
 guint
 e_book_async_authenticate_user (EBook                 *book,
 				const char            *user,
@@ -1347,14 +1439,14 @@ do_get_contact (gboolean sync,
 /**
  * e_book_get_contact:
  * @book: an #EBook
- * @id: a string
+ * @id: a unique string ID specifying the contact
  * @contact: an #EContact
  * @error: a #GError to set on failure
  *
  * Fills in @contact with the contents of the vcard in @book
  * corresponding to @id.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_get_contact (EBook       *book,
@@ -1371,6 +1463,17 @@ e_book_get_contact (EBook       *book,
 			       NULL, NULL);
 }
 
+/**
+ * e_book_async_get_contact:
+ * @book: an #EBook
+ * @id: a unique string ID specifying the contact
+ * @cb: function to call when operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Retrieves a contact specified by @id from @book.
+ *
+ * Return value: %FALSE if successful, %TRUE otherwise
+ **/
 guint
 e_book_async_get_contact (EBook                 *book,
 			  const char            *id,
@@ -1557,7 +1660,7 @@ do_remove_contacts (gboolean sync,
  *
  * Removes the contact with id @id from @book.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_remove_contact (EBook       *book,
@@ -1590,7 +1693,7 @@ e_book_remove_contact (EBook       *book,
  * have more than one id to remove, as some backends can implement it
  * as a batch request.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_remove_contacts (EBook    *book,
@@ -1605,6 +1708,17 @@ e_book_remove_contacts (EBook    *book,
 				   NULL, NULL);
 }
 
+/**
+ * e_book_async_remove_contact:
+ * @book: an #EBook
+ * @contact: an #EContact
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Removes @contact from @book.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise
+ **/
 guint
 e_book_async_remove_contact (EBook                 *book,
 			     EContact              *contact,
@@ -1621,6 +1735,17 @@ e_book_async_remove_contact (EBook                 *book,
 	return e_book_async_remove_contact_by_id (book, id, cb, closure);
 }
 
+/**
+ * e_book_async_remove_contact_by_id:
+ * @book: an #EBook
+ * @id: a unique ID string specifying the contact
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Removes the contact with id @id from @book.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise
+ **/
 guint
 e_book_async_remove_contact_by_id (EBook                 *book,
 				   const char            *id,
@@ -1637,6 +1762,20 @@ e_book_async_remove_contact_by_id (EBook                 *book,
 	return e_book_async_remove_contacts (book, list, cb, closure);
 }
 
+/**
+ * e_book_async_remove_contacts:
+ * @book: an #EBook
+ * @ids: an #GList of const char *id's
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Removes the contacts with ids from the list @ids from @book.  This is
+ * always more efficient than calling e_book_remove_contact_by_id if you
+ * have more than one id to remove, as some backends can implement it
+ * as a batch request.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise
+ **/
 guint
 e_book_async_remove_contacts (EBook                 *book,
 			      GList                 *ids,
@@ -1778,9 +1917,9 @@ do_get_book_view (gboolean sync,
  *
  * Query @book with @query, creating a #EBookView in @book_view with the fields
  * specified by @requested_fields and limited at @max_results records. On an
- * error, @error is set and #FALSE returned.
+ * error, @error is set and %FALSE returned.
  *
- * Return value: #TRUE if successful, #FALSE otherwise
+ * Return value: %TRUE if successful, %FALSE otherwise
  **/
 gboolean
 e_book_get_book_view (EBook       *book,
@@ -1799,6 +1938,20 @@ e_book_get_book_view (EBook       *book,
 				 NULL, NULL);
 }
 
+/**
+ * e_book_async_get_book_view:
+ * @book: an #EBook
+ * @query: an #EBookQuery
+ * @requested_fields: a #GList containing the names of fields to return, or NULL for all
+ * @max_results: the maximum number of contacts to show (or 0 for all)
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Query @book with @query, creating a #EBookView with the fields
+ * specified by @requested_fields and limited at @max_results records.
+ *
+ * Return value: %FALSE if successful, %TRUE otherwise
+ **/
 guint
 e_book_async_get_book_view (EBook                 *book,
 			    EBookQuery            *query,
@@ -1883,7 +2036,6 @@ e_book_response_get_book_view (EBook       *book,
 	g_mutex_unlock (book->priv->mutex);
 }
 
-
 static gboolean
 do_get_contacts (gboolean sync,
 		 EBook *book,
@@ -1990,9 +2142,9 @@ do_get_contacts (gboolean sync,
  * @error: a #GError to set on failure
  *
  * Query @book with @query, setting @contacts to the list of contacts which
- * matched. On failed, @error will be set and #FALSE returned.
+ * matched. On failed, @error will be set and %FALSE returned.
  *
- * Return value: #TRUE on success, #FALSE otherwise
+ * Return value: %TRUE on success, %FALSE otherwise
  **/
 gboolean
 e_book_get_contacts (EBook       *book,
@@ -2009,6 +2161,17 @@ e_book_get_contacts (EBook       *book,
 				NULL, NULL);
 }
 
+/**
+ * e_book_async_get_contacts:
+ * @book: an #EBook
+ * @query: an #EBookQuery
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Query @book with @query.
+ *
+ * Return value: %FALSE on success, %TRUE otherwise
+ **/
 guint
 e_book_async_get_contacts (EBook             *book,
 			   EBookQuery        *query,
@@ -2070,19 +2233,17 @@ e_book_response_get_contacts (EBook       *book,
 
 	op->list = g_list_copy (contact_list);
 	g_list_foreach (op->list, (GFunc)g_object_ref, NULL);
+	op->status = status;
 
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
-
 		g_cond_signal (op->cond);
 
 		g_mutex_unlock (op->mutex);
 	}
 	else {
 		op->book = g_object_ref (book);
-		op->status = status;
 		op->idle_id = g_idle_add (emit_async_get_contacts_response, op);
 		book->priv->pending_idles = g_list_prepend (book->priv->pending_idles,
 							    GINT_TO_POINTER (op->idle_id));
@@ -2331,18 +2492,16 @@ e_book_response_generic (EBook       *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
-
 		g_cond_signal (op->cond);
 
 		g_mutex_unlock (op->mutex);
 	}
 	else {
 		op->book = g_object_ref (book);
-		op->status = status;
 		op->idle_id = g_idle_add (emit_async_generic_response, op);
 		book->priv->pending_idles = g_list_prepend (book->priv->pending_idles,
 							    GINT_TO_POINTER (op->idle_id));
@@ -2366,7 +2525,7 @@ e_book_response_generic (EBook       *book,
  * blocked e_book function corresponding to current operation will
  * return with a status of E_BOOK_STATUS_CANCELLED.
  *
- * Return value: #TRUE on success, #FALSE otherwise
+ * Return value: %TRUE on success, %FALSE otherwise
  **/
 gboolean
 e_book_cancel (EBook   *book,
@@ -2384,7 +2543,7 @@ e_book_cancel (EBook   *book,
 	if (e_book_get_current_sync_op (book) == NULL) {
 		g_mutex_unlock (book->priv->mutex);
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_COULD_NOT_CANCEL,
-			     _("e_book_cancel: there is no current operation"));
+			     _("%s: there is no current operation"), "e_book_cacnel");
 		return FALSE;
 	}
 
@@ -2419,7 +2578,7 @@ e_book_cancel (EBook   *book,
 	}
 	else {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_COULD_NOT_CANCEL,
-			     _("e_book_cancel: couldn't cancel"));
+			     _("%s: couldn't cancel"), "e_book_cancel");
 		rv = FALSE;
 	}
 
@@ -2518,7 +2677,7 @@ do_open (gboolean sync,
 			/* Cancelled */
 			book->priv->load_state = E_BOOK_SOURCE_NOT_LOADED;
 			g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED,
-				     _("e_book_open: cancelled"));
+				     _("%s: cancelled"), "e_book_open");
 			return FALSE;
 		}
 		else if (status == E_BOOK_ERROR_OK) {
@@ -2537,12 +2696,12 @@ do_open (gboolean sync,
 /**
  * e_book_open:
  * @book: an #EBook
- * @only_if_exists: if #TRUE, fail if this book doesn't already exist otherwise create it first
+ * @only_if_exists: if %TRUE, fail if this book doesn't already exist, otherwise create it first
  * @error: a #GError to set on failure
  *
  * Opens the addressbook, making it ready for queries and other operations.
  *
- * Return value: #TRUE if the book was successfully opened, #FALSE otherwise.
+ * Return value: %TRUE if the book was successfully opened, %FALSE otherwise.
  */
 gboolean
 e_book_open (EBook     *book,
@@ -2556,6 +2715,18 @@ e_book_open (EBook     *book,
 			NULL, NULL);
 }
 
+/**
+ * e_book_async_open:
+ * @book: an #EBook
+ * @only_if_exists: if %TRUE, fail if this book doesn't already exist, otherwise create it first
+ * @open_response: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Opens the addressbook, making it ready for queries and other operations.
+ * This function does not block.
+ *
+ * Return value: %FALSE if successful, %TRUE otherwise.
+ **/
 guint
 e_book_async_open (EBook                 *book,
 		   gboolean               only_if_exists,
@@ -2621,18 +2792,16 @@ e_book_response_open (EBook       *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
-
 		g_cond_signal (op->cond);
 
 		g_mutex_unlock (op->mutex);
 	}
 	else {
 		op->book = g_object_ref (book);
-		op->status = status;
 		op->idle_id = g_idle_add (emit_async_open_response, op);
 		book->priv->pending_idles = g_list_prepend (book->priv->pending_idles,
 							    GINT_TO_POINTER (op->idle_id));
@@ -2722,10 +2891,10 @@ do_remove (gboolean sync,
  * @book: an #EBook
  * @error: a #GError to set on failure
  *
- * Remove the backing data for this #EBook. For example, with the file backend this
+ * Removes the backing data for this #EBook. For example, with the file backend this
  * deletes the database file. You cannot get it back!
  *
- * Return value: #TRUE on success, #FALSE on failure.
+ * Return value: %TRUE on success, %FALSE on failure.
  */
 gboolean
 e_book_remove (EBook   *book,
@@ -2739,6 +2908,17 @@ e_book_remove (EBook   *book,
 
 }
 
+/**
+ * e_book_async_remove:
+ * @book: an #EBook
+ * @cb: a function to call when the operation finishes
+ * @closure: data to pass to callback function
+ *
+ * Remove the backing data for this #EBook. For example, with the file backend this
+ * deletes the database file. You cannot get it back!
+ *
+ * Return value: %FALSE if successful, %TRUE otherwise.
+ **/
 guint
 e_book_async_remove (EBook   *book,
 		     EBookCallback cb,
@@ -2771,18 +2951,16 @@ e_book_response_remove (EBook       *book,
 		return;
 	}
 
+	op->status = status;
 	if (op->synchronous) {
 		g_mutex_lock (op->mutex);
 
-		op->status = status;
-
 		g_cond_signal (op->cond);
 
 		g_mutex_unlock (op->mutex);
 	}
 	else {
 		op->book = g_object_ref (book);
-		op->status = status;
 		op->idle_id = g_idle_add (emit_async_generic_response, op);
 		book->priv->pending_idles = g_list_prepend (book->priv->pending_idles,
 							    GINT_TO_POINTER (op->idle_id));
@@ -2809,7 +2987,43 @@ e_book_idle_writable (gpointer data)
 	return FALSE;
 }
 
-
+static gboolean 
+e_book_idle_connection (gpointer data)
+{
+	EBook *book = data;
+	gboolean connected;
+
+	g_mutex_lock (book->priv->mutex);
+	connected = book->priv->connected;
+	book->priv->connection_idle_id = 0;
+	g_mutex_unlock (book->priv->mutex);
+
+	g_signal_emit (G_OBJECT (book), e_book_signals [CONNECTION_STATUS], 0, connected);
+
+	g_object_unref (book);
+
+	return FALSE;
+}
+
+static gboolean 
+e_book_idle_auth_required (gpointer data)
+{
+	EBook *book = data;
+	gboolean connected;
+
+	g_mutex_lock (book->priv->mutex);
+	connected = book->priv->connected;
+	book->priv->auth_idle_id = 0;
+	g_mutex_unlock (book->priv->mutex);
+
+	g_signal_emit (G_OBJECT (book), e_book_signals [AUTH_REQUIRED], 0);
+
+	g_object_unref (book);
+
+	return FALSE;
+
+
+}
 
 static void
 e_book_handle_response (EBookListener *listener, EBookListenerResponse *resp, EBook *book)
@@ -2864,6 +3078,24 @@ e_book_handle_response (EBookListener *listener, EBookListenerResponse *resp, EB
 		g_mutex_unlock (book->priv->mutex);
 
 		break;
+	case LinkStatusEvent:
+		book->priv->connected = resp->connected;
+		g_mutex_lock (book->priv->mutex);
+		if (book->priv->connection_idle_id == 0) {
+			g_object_ref (book);
+			book->priv->connection_idle_id = g_idle_add (e_book_idle_connection, book);
+		}
+		g_mutex_unlock (book->priv->mutex);
+		break;
+	case AuthRequiredEvent:
+		g_mutex_lock (book->priv->mutex);
+		if (book->priv->auth_idle_id == 0) {
+			g_object_ref (book);
+			book->priv->auth_idle_id = g_idle_add (e_book_idle_auth_required, book);
+		}
+		g_mutex_unlock (book->priv->mutex);
+		break;
+		
 	default:
 		g_error ("EBook: Unknown response code %d!\n",
 			 resp->op);
@@ -2879,7 +3111,7 @@ e_book_handle_response (EBookListener *listener, EBookListenerResponse *resp, EB
  *
  * Unload the URI that this book had previously loaded.
  *
- * Return value: #TRUE on success, #FALSE otherwise.
+ * Return value: %TRUE on success, %FALSE otherwise.
  */
 static gboolean
 e_book_unload_uri (EBook   *book,
@@ -3006,7 +3238,7 @@ fetch_corba_book (EBook       *book,
 	uri = e_source_get_uri (source);
 	if (!uri) {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_OTHER_ERROR,
-			     _("e_book_load_uri: Invalid source."));
+			     _("%s: Invalid source."), "e_book_load_uri");
 		return FALSE;
 	}
 
@@ -3014,7 +3246,7 @@ fetch_corba_book (EBook       *book,
 	factories = activate_factories_for_uri (book, uri);
 	if (!factories) {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_PROTOCOL_NOT_SUPPORTED,
-			     _("e_book_load_uri: no factories available for uri `%s'"), uri);
+			     _("%s: no factories available for uri `%s'"), "e_book_load_uri", uri);
 		return FALSE;
 	}
 
@@ -3026,7 +3258,7 @@ fetch_corba_book (EBook       *book,
 	if (book->priv->listener == NULL) {
 		g_warning ("e_book_load_uri: Could not create EBookListener!\n");
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_OTHER_ERROR,
-			     _("e_book_load_uri: Could not create EBookListener"));
+			     _("%s: Could not create EBookListener"), "e_book_load_uri");
 		return FALSE;
 	}
 	book->priv->listener_signal = g_signal_connect_object (book->priv->listener, "response",
@@ -3078,7 +3310,7 @@ fetch_corba_book (EBook       *book,
 	}
 	else {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_PROTOCOL_NOT_SUPPORTED,
-			     _("e_book_new: no factories available for uri `%s'"), uri);
+			     _("%s: no factories available for uri `%s'"), "e_book_new", uri);
 	}
 		
 	return rv;
@@ -3174,7 +3406,7 @@ e_book_get_static_capabilities (EBook   *book,
  * Check to see if the backend for this address book supports the capability
  * @cap.
  *
- * Return value: #TRUE if the backend supports @cap, #FALSE otherwise.
+ * Return value: %TRUE if the backend supports @cap, %FALSE otherwise.
  */
 gboolean
 e_book_check_static_capability (EBook *book,
@@ -3199,7 +3431,7 @@ e_book_check_static_capability (EBook *book,
  *
  * Check if this book has been opened.
  *
- * Return value: #TRUE if this book has been opened, otherwise #FALSE.
+ * Return value: %TRUE if this book has been opened, otherwise %FALSE.
  */
 gboolean
 e_book_is_opened (EBook *book)
@@ -3218,7 +3450,7 @@ e_book_is_opened (EBook *book)
  * 
  * Check if this book is writable.
  * 
- * Return value: #TRUE if this book is writable, otherwise #FALSE.
+ * Return value: %TRUE if this book is writable, otherwise %FALSE.
  */
 gboolean
 e_book_is_writable (EBook *book)
@@ -3228,10 +3460,36 @@ e_book_is_writable (EBook *book)
 	return book->priv->writable;
 }
 
+/**
+ * e_book_is_online:
+ * @book: an #EBook
+ *
+ * Check if this book is connected.
+ *
+ * Return value: %TRUE if this book is connected, otherwise %FALSE.
+ **/
+gboolean 
+e_book_is_online (EBook *book)
+{
+	g_return_val_if_fail (book && E_IS_BOOK (book), FALSE);
 
-
+	return book->priv->connected;
+
+}
 
 #define SELF_UID_KEY "/apps/evolution/addressbook/self/self_uid"
+
+/**
+ * e_book_get_self:
+ * @contact: an #EContact pointer to set
+ * @book: an #EBook pointer to set
+ * @error: a #GError to set on failure
+ *
+ * Get the #EContact referring to the user of the address book
+ * and set it in @contact and @book.
+ *
+ * Return value: %TRUE if successful, otherwise %FALSE.
+ **/
 gboolean
 e_book_get_self (EContact **contact, EBook **book, GError **error)
 {
@@ -3263,7 +3521,7 @@ e_book_get_self (EContact **contact, EBook **book, GError **error)
 		g_object_unref (*book);
 		*book = NULL;
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_NO_SELF_CONTACT,
-			     _("e_book_get_self: there was no self contact uid stored in gconf"));
+			     _("%s: there was no self contact uid stored in gconf"), "e_book_get_self");
 		return FALSE;
 	}
 
@@ -3278,6 +3536,17 @@ e_book_get_self (EContact **contact, EBook **book, GError **error)
 	return TRUE;
 }
 
+/**
+ * e_book_set_self:
+ * @book: an #EBook
+ * @contact: an #EContact
+ * @error: a #GError to set on failure
+ *
+ * Specify that @contact residing in @book is the #EContact that
+ * refers to the user of the address book.
+ *
+ * Return value: %TRUE if successful, %FALSE otherwise.
+ **/
 gboolean
 e_book_set_self (EBook *book, EContact *contact, GError **error)
 {
@@ -3293,6 +3562,14 @@ e_book_set_self (EBook *book, EContact *contact, GError **error)
 	return TRUE;
 }
 
+/**
+ * e_book_is_self:
+ * @contact: an #EContact
+ *
+ * Check if @contact is the user of the address book.
+ *
+ * Return value: %TRUE if @contact is the user, %FALSE otherwise.
+ **/
 gboolean
 e_book_is_self (EContact *contact)
 {
@@ -3325,7 +3602,7 @@ e_book_is_self (EContact *contact)
  * sets the #ESource of the #EBook as the "default" addressbook.  This is the source
  * that will be loaded in the e_book_get_default_addressbook call.
  * 
- * Return value: #TRUE if the setting was stored in libebook's ESourceList, otherwise #FALSE.
+ * Return value: %TRUE if the setting was stored in libebook's ESourceList, otherwise %FALSE.
  */
 gboolean
 e_book_set_default_addressbook (EBook *book, GError **error)
@@ -3342,14 +3619,14 @@ e_book_set_default_addressbook (EBook *book, GError **error)
 
 
 /**
- * e_book_set_default_addressbook:
+ * e_book_set_default_source:
  * @source: An #ESource pointer
  * @error: A #GError pointer
  * 
  * sets @source as the "default" addressbook.  This is the source that
  * will be loaded in the e_book_get_default_addressbook call.
  * 
- * Return value: #TRUE if the setting was stored in libebook's ESourceList, otherwise #FALSE.
+ * Return value: %TRUE if the setting was stored in libebook's ESourceList, otherwise %FALSE.
  */
 gboolean
 e_book_set_default_source (ESource *source, GError **error)
@@ -3374,7 +3651,7 @@ e_book_set_default_source (ESource *source, GError **error)
 	source = e_source_list_peek_source_by_uid (sources, uid);
 	if (!source) {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_NO_SUCH_SOURCE,
-			     _("e_book_set_default_source: there was no source for uid `%s' stored in gconf."), uid);
+			     _("%s: there was no source for uid `%s' stored in gconf."), "e_book_set_default_source", uid);
 		g_object_unref (sources);
 		return FALSE;
 	}
@@ -3409,7 +3686,7 @@ e_book_set_default_source (ESource *source, GError **error)
  * Populate *addressbook_sources with the list of all sources which have been
  * added to Evolution.
  *
- * Return value: #TRUE if @addressbook_sources was set, otherwise #FALSE.
+ * Return value: %TRUE if @addressbook_sources was set, otherwise %FALSE.
  */
 gboolean
 e_book_get_addressbooks (ESourceList **addressbook_sources, GError **error)
@@ -3743,6 +4020,25 @@ e_book_class_init (EBookClass *klass)
 			      e_book_marshal_NONE__BOOL,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_BOOLEAN);
+	
+	e_book_signals [CONNECTION_STATUS] =
+		g_signal_new ("connection_status",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EBookClass, connection_status),
+			      NULL, NULL,
+			      e_book_marshal_NONE__BOOL,
+			      G_TYPE_NONE, 1,
+			      G_TYPE_BOOLEAN);
+
+	e_book_signals [AUTH_REQUIRED] =
+		g_signal_new ("auth_required",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EBookClass, auth_required),
+			      NULL, NULL,
+			      e_book_marshal_NONE__NONE,
+			      G_TYPE_NONE, 0);
 
 	e_book_signals [BACKEND_DIED] =
 		g_signal_new ("backend_died",
