@@ -628,8 +628,11 @@ get_notification_value (SoupSoapParameter *param, const char *param_name)
 		subparam = soup_soap_parameter_get_first_child_by_name (subparam, "mail");
 		if (subparam)
 			value = soup_soap_parameter_get_string_value (subparam);
-		if (value && !g_ascii_strcasecmp (value, "1"))
-			return E_GW_ITEM_NOTIFY_MAIL;
+		if (value && !g_ascii_strcasecmp (value, "1")) {
+			g_free (value), value = NULL;
+	 		return E_GW_ITEM_NOTIFY_MAIL;
+		}
+		g_free (value), value = NULL;
 	}
 	return E_GW_ITEM_NOTIFY_NONE;
 }
@@ -868,6 +871,12 @@ set_common_addressbook_item_fields_from_soap_parameter (EGwItem *item, SoupSoapP
 		item->priv->id = g_strdup (value);
 	}
 	value = NULL;
+	subparam = soup_soap_parameter_get_first_child_by_name (param, "modified");
+	if (subparam) {
+		value = soup_soap_parameter_get_string_value (subparam);
+		g_hash_table_insert (simple_fields, "modified_time", value);
+	}
+	value = NULL;
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "comment");
 	if(subparam) {
 		value = soup_soap_parameter_get_string_value (subparam);
@@ -1021,8 +1030,12 @@ set_contact_fields_from_soap_parameter (EGwItem *item, SoupSoapParameter *param)
 		}
 		for ( temp = soup_soap_parameter_get_first_child (subparam); temp != NULL; temp = soup_soap_parameter_get_next_child (temp)) {
 			value = soup_soap_parameter_get_string_value (temp);
-			if (value && (!primary_email ||  !g_str_equal (primary_email, value)))
-				item->priv->email_list = g_list_append (item->priv->email_list, value);
+			if (value) {
+				if (!primary_email || !g_str_equal (primary_email, value))
+					item->priv->email_list = g_list_append (item->priv->email_list, value);
+				else
+					g_free (value);
+			}
 		}
 		g_free (primary_email);
 	}
@@ -1117,8 +1130,8 @@ set_contact_fields_from_soap_parameter (EGwItem *item, SoupSoapParameter *param)
 			value = soup_soap_parameter_get_property(temp, "type");
 			if (value)
 				g_hash_table_insert (item->priv->addresses, value, address);
-			 			
-			
+			else
+				free_postal_address (address);
 		}
 		
 	}
@@ -1730,8 +1743,8 @@ e_gw_item_new_from_soap_parameter (const char *email, const char *container, Sou
 		} else if (!g_ascii_strcasecmp (name, "to")) {
 			char *to ;
 			to = soup_soap_parameter_get_string_value (child) ;
-			e_gw_item_set_to (item,to) ;
-
+			e_gw_item_set_to (item, to);
+			g_free (to);
 		} else if (!g_ascii_strcasecmp (name, "iCalId"))
 			item->priv->icalid = soup_soap_parameter_get_string_value (child);
 
@@ -1814,7 +1827,11 @@ e_gw_item_new_from_soap_parameter (const char *email, const char *container, Sou
 			item->priv->place = soup_soap_parameter_get_string_value (child);
 
 		else if (!g_ascii_strcasecmp (name, "taskPriority")) {
-			e_gw_item_set_task_priority (item, soup_soap_parameter_get_string_value (child));
+			char *priority;
+
+			priority = soup_soap_parameter_get_string_value (child);
+			e_gw_item_set_task_priority (item, priority);
+			g_free (priority);
 		}
 
 		else if (!g_ascii_strcasecmp (name, "startDate")) {
@@ -2521,8 +2538,8 @@ append_gw_item_options (SoupSoapMessage *msg, EGwItem *item)
 	soup_soap_message_end_element (msg);
 }
 
-static void
-add_distribution_to_soap_message (EGwItem *item, SoupSoapMessage *msg)
+void
+e_gw_item_add_distribution_to_soap_message (EGwItem *item, SoupSoapMessage *msg)
 {
 	GSList *rl;
 	EGwItemPrivate *priv;
@@ -2549,7 +2566,7 @@ add_distribution_to_soap_message (EGwItem *item, SoupSoapMessage *msg)
 	/* add each recipient */
 	for (rl = recipient_list; rl != NULL; rl = rl->next) {
 		char *dist_type;
-		char *status;
+		char *status = NULL;
 
 		EGwItemRecipient *recipient = (EGwItemRecipient *) rl->data;
 		
@@ -2572,7 +2589,8 @@ add_distribution_to_soap_message (EGwItem *item, SoupSoapMessage *msg)
 			status = "declined";
 		else
 			status = "";
-		e_gw_message_write_string_parameter (msg, "recipientStatus", NULL, status);
+		if (status && *status)
+			e_gw_message_write_string_parameter (msg, "recipientStatus", NULL, status);
 		
 		soup_soap_message_end_element (msg);		
 	}
@@ -2692,7 +2710,7 @@ e_gw_item_set_calendar_item_elements (EGwItem *item, SoupSoapMessage *msg)
 	e_gw_message_write_string_parameter (msg, "subject", NULL, priv->subject ? priv->subject : "");
 
 	if (priv->recipient_list != NULL) {
-		add_distribution_to_soap_message (item, msg);
+		e_gw_item_add_distribution_to_soap_message (item, msg);
 		if (priv->set_sendoptions)
 			append_gw_item_options (msg, item);
 	}
@@ -2781,7 +2799,7 @@ e_gw_item_append_to_soap_message (EGwItem *item, SoupSoapMessage *msg)
 		if (priv->subject)
 			e_gw_message_write_string_parameter (msg, "subject", NULL, priv->subject) ;
 		/*distribution*/
-		add_distribution_to_soap_message(item, msg) ;
+		e_gw_item_add_distribution_to_soap_message(item, msg) ;
 		
 		if (priv->set_sendoptions) {
 			/* item options */
